@@ -15,7 +15,7 @@ from pmb.config.merge_with_args import merge_with_args
 #
 # Exported variables (internal configuration)
 #
-version = "1.29.1"
+version = "1.31.0"
 pmb_src = os.path.normpath(os.path.realpath(__file__) + "/../../..")
 apk_keys_path = pmb_src + "/pmb/data/keys"
 
@@ -24,9 +24,9 @@ apk_keys_path = pmb_src + "/pmb/data/keys"
 # Update this frequently to prevent a MITM attack with an outdated version
 # (which may contain a vulnerable apk/openssl, and allows an attacker to
 # exploit the system!)
-apk_tools_min_version = {"edge": "2.12.1-r0",
-                         "v3.13": "2.12.1-r0",
-                         "v3.12": "2.10.5-r1"}
+apk_tools_min_version = {"edge": "2.12.5-r0",
+                         "v3.13": "2.12.5-r0",
+                         "v3.12": "2.10.6-r0"}
 
 # postmarketOS aports compatibility (checked against "version" in pmaports.cfg)
 pmaports_min_version = "7"
@@ -34,10 +34,10 @@ pmaports_min_version = "7"
 # Version of the work folder (as asked during 'pmbootstrap init'). Increase
 # this number, whenever migration is required and provide the migration code,
 # see migrate_work_folder()).
-work_version = 5
+work_version = 6
 
 # Minimum required version of postmarketos-ondev (pmbootstrap install --ondev).
-# Try to support the current versions of all channels (edge, stable). When
+# Try to support the current versions of all channels (edge, v21.03). When
 # bumping > 0.4.0, remove compat code in pmb/install/_install.py (search for
 # get_ondev_pkgver).
 ondev_min_version = "0.2.0"
@@ -94,7 +94,7 @@ defaults = {
     "keymap": "",
     "locale": "C.UTF-8",
     "log": "$WORK/log.txt",
-    "mirror_alpine": "http://dl-2.alpinelinux.org/alpine/",
+    "mirror_alpine": "http://dl-cdn.alpinelinux.org/alpine/",
     "mirrors_postmarketos": ["http://mirror.postmarketos.org/postmarketos/"],
     "nonfree_firmware": True,
     "nonfree_userland": False,
@@ -105,7 +105,7 @@ defaults = {
     "ui_extras": False,
     "user": "user",
     "work": os.path.expanduser("~") + "/.local/var/pmbootstrap",
-    "boot_size": "128",
+    "boot_size": "256",
     "extra_space": "0",
     "sudo_timer": False
 }
@@ -137,7 +137,16 @@ locales = [
     "sv_SE.UTF-8"
 ]
 
+# Supported filesystems and their fstools packages
+filesystems = {"ext2": "e2fsprogs",
+               "ext4": "e2fsprogs",
+               "f2fs": "f2fs-tools",
+               "fat16": "dosfstools",
+               "fat32": "dosfstools"}
 
+# Legacy channels and their new names (pmb#2015)
+pmaports_channels_legacy = {"stable": "v20.05",
+                            "stable-next": "v21.03"}
 #
 # CHROOT
 #
@@ -165,7 +174,7 @@ chroot_host_path = os.environ["PATH"] + ":/usr/sbin/"
 # Folders, that get mounted inside the chroot
 # $WORK gets replaced with args.work
 # $ARCH gets replaced with the chroot architecture (eg. x86_64, armhf)
-# $CHANNEL gets replaced with the release channel (e.g. edge, stable)
+# $CHANNEL gets replaced with the release channel (e.g. edge, v21.03)
 chroot_mount_bind = {
     "/proc": "/proc",
     "$WORK/cache_apk_$ARCH": "/var/cache/apk",
@@ -242,6 +251,7 @@ necessary_kconfig_options = {
             "SAMSUNG_TUI": False,
             "SEC_RESTRICT_ROOTING": False,
             "SYSVIPC": True,
+            "TMPFS_POSIX_ACL": True,
             "TZDEV": False,
             "USE_VFB": False,
             "VT": True,
@@ -410,6 +420,7 @@ deviceinfo_attributes = [
     "sd_embed_firmware_step_size",
     "partition_blacklist",
     "boot_part_start",
+    "root_filesystem",
 
     # weston
     "weston_pixman_type",
@@ -446,7 +457,7 @@ default_ip = "172.16.42.1"
 # Packages, that will be installed inside the native chroot to perform
 # the installation to the device.
 # util-linux: losetup, fallocate
-install_native_packages = ["cryptsetup", "util-linux", "e2fsprogs", "parted", "dosfstools"]
+install_native_packages = ["cryptsetup", "util-linux", "parted"]
 install_device_packages = ["postmarketos-base"]
 
 # Groups for the default user
@@ -570,7 +581,7 @@ flashers = {
         }
     },
     "uuu": {
-        "depends": ["uuu"],
+        "depends": ["nxp-mfgtools-uuu"],
         "actions": {
             "flash_rootfs": [
                 # There's a bug(?) in uuu where it clobbers the path in the cmd
