@@ -64,7 +64,9 @@ def get_nonfree_packages(args, device):
               ["device-nokia-n900-nonfree-firmware"]
     """
     # Read subpackages
-    apkbuild = pmb.parse.apkbuild(args, pmb.helpers.devices.find_path(args, device, 'APKBUILD'))
+    apkbuild = pmb.parse.apkbuild(args,
+                                  pmb.helpers.devices.find_path(args, device,
+                                                                'APKBUILD'))
     subpackages = apkbuild["subpackages"]
 
     # Check for firmware and userland
@@ -94,7 +96,7 @@ def get_kernel_package(args, device):
     # Sanity check
     if args.kernel not in kernels:
         raise RuntimeError("Selected kernel (" + args.kernel + ") is not"
-                           " configured for device " + device + ". Please"
+                           " valid for device " + device + ". Please"
                            " run 'pmbootstrap init' to select a valid kernel.")
 
     # Selected kernel subpackage
@@ -138,8 +140,8 @@ def copy_files_from_chroot(args, suffix):
         rsync_flags = "-a"
         if args.verbose:
             rsync_flags += "vP"
-        pmb.chroot.root(args, ["rsync", rsync_flags, "--delete"] + folders + ["/mnt/install/"],
-                        working_dir=mountpoint)
+        pmb.chroot.root(args, ["rsync", rsync_flags, "--delete"] + folders +
+                        ["/mnt/install/"], working_dir=mountpoint)
         pmb.chroot.root(args, ["rm", "-rf", "/mnt/install/home"])
     else:
         pmb.chroot.root(args, ["cp", "-a"] + folders + ["/mnt/install/"],
@@ -202,12 +204,14 @@ def set_user(args):
         pmb.chroot.root(args, ["addgroup", args.user, group], suffix)
 
 
-def setup_login(args):
+def setup_login(args, suffix):
     """
-    Loop until the password for user has been set successfully, and disable root
-    login.
+    Loop until the password for user has been set successfully, and disable
+    root login.
+
+    :param suffix: of the chroot, where passwd will be execute (either the
+                   f"rootfs_{args.device}", or f"installer_{args.device}")
     """
-    suffix = "rootfs_" + args.device
     if not args.on_device_installer:
         # User password
         logging.info(" *** SET LOGIN PASSWORD FOR: '" + args.user + "' ***")
@@ -237,8 +241,9 @@ def copy_ssh_keys(args):
             keys += infile.readlines()
 
     if not len(keys):
-        logging.info("NOTE: Public SSH keys not found. Since no SSH keys " +
-                     "were copied, you will need to use SSH password authentication!")
+        logging.info("NOTE: Public SSH keys not found. Since no SSH keys "
+                     "were copied, you will need to use SSH password "
+                     "authentication!")
         return
 
     authorized_keys = args.work + "/chroot_native/tmp/authorized_keys"
@@ -247,10 +252,11 @@ def copy_ssh_keys(args):
         outfile.write("%s" % key)
     outfile.close()
 
-    target = args.work + "/chroot_native/mnt/install/home/" + args.user + "/.ssh"
+    target = f"{args.work}/chroot_native/mnt/install/home/{args.user}/.ssh"
     pmb.helpers.run.root(args, ["mkdir", target])
     pmb.helpers.run.root(args, ["chmod", "700", target])
-    pmb.helpers.run.root(args, ["cp", authorized_keys, target + "/authorized_keys"])
+    pmb.helpers.run.root(args, ["cp", authorized_keys, target +
+                                "/authorized_keys"])
     pmb.helpers.run.root(args, ["rm", authorized_keys])
     pmb.helpers.run.root(args, ["chown", "-R", "10000:10000", target])
 
@@ -292,8 +298,8 @@ def setup_keymap(args):
             config = config.splitlines()[-1]
             old_text = "Option *\\\"XkbLayout\\\" *\\\".*\\\""
             new_text = "Option \\\"XkbLayout\\\" \\\"" + layout + "\\\""
-            pmb.chroot.root(args, ["sed", "-i", "s/" + old_text + "/" + new_text + "/", config],
-                            suffix)
+            pmb.chroot.root(args, ["sed", "-i", "s/" + old_text + "/" +
+                            new_text + "/", config], suffix)
     else:
         logging.info("NOTE: No valid keymap specified for device")
 
@@ -321,6 +327,44 @@ def setup_hostname(args):
     pmb.chroot.root(args, ["sed", "-i", "-e", regex, "/etc/hosts"], suffix)
 
 
+def disable_sshd(args):
+    if not args.no_sshd:
+        return
+
+    # check=False: rc-update doesn't exit with 0 if already disabled
+    suffix = f"rootfs_{args.device}"
+    pmb.chroot.root(args, ["rc-update", "del", "sshd", "default"], suffix,
+                    check=False)
+
+    # Verify that it's gone
+    sshd_files = pmb.helpers.run.root(
+        args, ["find", "-name", "sshd"], output_return=True,
+        working_dir=f"{args.work}/chroot_{suffix}/etc/runlevels")
+    if sshd_files:
+        raise RuntimeError(f"Failed to disable sshd service: {sshd_files}")
+
+
+def print_sshd_info(args):
+    logging.info("")  # make the note stand out
+    logging.info("*** SSH DAEMON INFORMATION ***")
+
+    if not args.ondev_no_rootfs:
+        if args.no_sshd:
+            logging.info("SSH daemon is disabled (--no-sshd).")
+        else:
+            logging.info("SSH daemon is enabled (disable with --no-sshd).")
+            logging.info(f"Login as '{args.user}' with the password given"
+                         " during installation.")
+
+    if args.on_device_installer:
+        # We don't disable sshd in the installer OS. If the device is reachable
+        # on the network by default (e.g. Raspberry Pi), one can lock down the
+        # installer OS down by disabling the debug user (see wiki page).
+        logging.info("SSH daemon is enabled in the installer OS, to allow"
+                     " debugging the installer image.")
+        logging.info("More info: https://postmarketos.org/ondev-debug")
+
+
 def embed_firmware(args, suffix):
     """
     This method will embed firmware, located at /usr/share, that are specified
@@ -400,12 +444,12 @@ def sanity_check_sdcard(args):
     device = args.sdcard
     device_name = os.path.basename(device)
     if not os.path.exists(device):
-        raise RuntimeError("{} doesn't exist, is the sdcard plugged?".format(device))
+        raise RuntimeError(f"{device} doesn't exist, is the sdcard plugged?")
     if os.path.isdir('/sys/class/block/{}'.format(device_name)):
         with open('/sys/class/block/{}/ro'.format(device_name), 'r') as handle:
             ro = handle.read()
         if ro == '1\n':
-            raise RuntimeError("{} is read-only, is the sdcard locked?".format(device))
+            raise RuntimeError(f"{device} is read-only, is the sdcard locked?")
 
 
 def sanity_check_sdcard_size(args):
@@ -425,10 +469,12 @@ def sanity_check_sdcard_size(args):
 
     # Warn if the size is larger than 100GiB
     if size > (100 * 2 * 1024 * 1024):
-        if not pmb.helpers.cli.confirm(args, f"WARNING: The target disk ({devpath}) is"
-                                             " larger than a usual SD card (>100GiB)."
-                                             " Are you sure you want to overwrite"
-                                             f" this {human} disk?", no_assumptions=True):
+        if not pmb.helpers.cli.confirm(args,
+                                       f"WARNING: The target disk ({devpath}) "
+                                       "is larger than a usual SD card "
+                                       "(>100GiB). Are you sure you want to "
+                                       f"overwrite this {human} disk?",
+                                       no_assumptions=True):
             raise RuntimeError("Aborted.")
 
 
@@ -483,7 +529,15 @@ def install_system_image(args, size_reserve, suffix, step, steps,
     create_home_from_skel(args)
     configure_apk(args)
     copy_ssh_keys(args)
-    embed_firmware(args, suffix)
+
+    # Don't try to embed firmware on split images since there's no
+    # place to put it and it will end up in /dev of the chroot instead
+    if not split:
+        embed_firmware(args, suffix)
+
+    if sdcard:
+        logging.info("Unmounting SD card (this may take a while "
+                     "to sync, please wait)")
     pmb.chroot.shutdown(args, True)
 
     # Convert rootfs to sparse using img2simg
@@ -505,6 +559,7 @@ def install_system_image(args, size_reserve, suffix, step, steps,
 def print_flash_info(args):
     """ Print flashing information, based on the deviceinfo data and the
         pmbootstrap arguments. """
+    logging.info("")  # make the note stand out
     logging.info("*** FLASHING INFORMATION ***")
 
     # System flash information
@@ -643,6 +698,9 @@ def install_on_device_installer(args, step, steps):
         logging.info(f"(native) rm {img_boot}")
         pmb.chroot.root(args, ["rm", f"/home/pmos/rootfs/{img_boot}"])
 
+    # Disable root login
+    setup_login(args, suffix_installer)
+
     # Generate installer image
     size_reserve = round(os.path.getsize(img_path_dest) / 1024 / 1024) + 200
     boot_label = "pmOS_inst_boot"
@@ -670,7 +728,8 @@ def create_device_rootfs(args, step, steps):
                         get_nonfree_packages(args, args.device) +
                         pmb.install.ui.get_recommends(args))
     if not args.install_base:
-        install_packages = [p for p in install_packages if p != "postmarketos-base"]
+        install_packages = [p for p in install_packages
+                            if p != "postmarketos-base"]
     if args.ui.lower() != "none":
         install_packages += ["postmarketos-ui-" + args.ui]
         if args.ui_extras:
@@ -694,13 +753,12 @@ def create_device_rootfs(args, step, steps):
     # Install all packages to device rootfs chroot (and rebuild the initramfs,
     # because that doesn't always happen automatically yet, e.g. when the user
     # installed a hook without pmbootstrap - see #69 for more info)
-    suffix = "rootfs_" + args.device
     pmb.chroot.apk.install(args, install_packages, suffix)
     for flavor in pmb.chroot.other.kernel_flavors_installed(args, suffix):
         pmb.chroot.initfs.build(args, flavor, suffix)
 
     # Set the user password
-    setup_login(args)
+    setup_login(args, suffix)
 
     # Set the keymap if the device requires it
     setup_keymap(args)
@@ -717,6 +775,8 @@ def create_device_rootfs(args, step, steps):
     # Set the hostname as the device name
     setup_hostname(args)
 
+    disable_sshd(args)
+
 
 def install(args):
     # Sanity checks
@@ -758,4 +818,9 @@ def install(args):
     else:
         install_system_image(args, 0, f"rootfs_{args.device}", step, steps,
                              split=args.split, sdcard=args.sdcard)
+
     print_flash_info(args)
+    print_sshd_info(args)
+
+    # Leave space before 'chroot still active' note
+    logging.info("")
