@@ -50,6 +50,10 @@ def arguments_install(subparser):
     ret = subparser.add_parser("install", help="set up device specific"
                                " chroot and install to SD card or image file")
 
+    # Other arguments (that don't fit categories below)
+    ret.add_argument("--no-sshd", action="store_true",
+                     help="do not enable the SSH daemon by default")
+
     # Image type
     group_desc = ret.add_argument_group(
         "optional image type",
@@ -151,6 +155,11 @@ def arguments_install(subparser):
                             " 'pmbootstrap install' run or by providing it"
                             " as CHROOT_DEST with --cp", action="store_true")
 
+    # Other
+    group = ret.add_argument_group("other optional arguments")
+    group.add_argument("--filesystem", help="root filesystem type",
+                       choices=["ext4", "f2fs"])
+
 
 def arguments_export(subparser):
     ret = subparser.add_parser("export", help="create convenience symlinks"
@@ -431,10 +440,10 @@ def arguments_kconfig(subparser):
     edit = sub.add_parser("edit", help="edit kernel aport config")
     edit.add_argument("--arch", choices=arch_choices, dest="arch")
     edit.add_argument("-x", dest="xconfig", action="store_true",
-                      help="use xconfig rather than ncurses for kernel"
+                      help="use xconfig rather than menuconfig for kernel"
                            " configuration")
-    edit.add_argument("-g", dest="gconfig", action="store_true",
-                      help="use gconfig rather than ncurses for kernel"
+    edit.add_argument("-n", dest="nconfig", action="store_true",
+                      help="use nconfig rather than menuconfig for kernel"
                            " configuration")
     edit_package = edit.add_argument("package", nargs='?')
     if argcomplete:
