@@ -125,9 +125,9 @@ def test_aportgen_device_wizard(args, monkeypatch):
     deviceinfo, apkbuild, apkbuild_linux = generate(args, monkeypatch, answers)
     assert apkbuild["pkgname"] == "device-testsuite-testdevice"
     assert apkbuild["pkgdesc"] == "Testsuite Testdevice"
-    assert apkbuild["depends"] == ["postmarketos-base",
-                                   "linux-testsuite-testdevice",
-                                   "mesa-dri-gallium"]
+    assert apkbuild["depends"] == ["linux-testsuite-testdevice",
+                                   "mesa-dri-gallium",
+                                   "postmarketos-base"]
 
     assert apkbuild_linux["pkgname"] == "linux-testsuite-testdevice"
     assert apkbuild_linux["pkgdesc"] == "Testsuite Testdevice kernel fork"
@@ -162,16 +162,20 @@ def test_aportgen_device_wizard(args, monkeypatch):
     answers["Flash method"] = "fastboot"
     answers["Path"] = ""
     deviceinfo, apkbuild, apkbuild_linux = generate(args, monkeypatch, answers)
-    assert apkbuild["depends"] == ["postmarketos-base",
-                                   "linux-testsuite-testdevice", "mkbootimg",
-                                   "mesa-dri-gallium"]
+    assert apkbuild["depends"] == ["linux-testsuite-testdevice",
+                                   "mesa-dri-gallium",
+                                   "mkbootimg",
+                                   "postmarketos-base"]
+
     assert deviceinfo["flash_method"] == answers["Flash method"]
     assert deviceinfo["generate_bootimg"] == "true"
 
     # 0xffff (legacy uboot initfs)
     answers["Flash method"] = "0xffff"
     deviceinfo, apkbuild, apkbuild_linux = generate(args, monkeypatch, answers)
-    assert apkbuild["depends"] == ["postmarketos-base",
-                                   "linux-testsuite-testdevice", "uboot-tools",
-                                   "mesa-dri-gallium"]
+    assert apkbuild["depends"] == ["linux-testsuite-testdevice",
+                                   "mesa-dri-gallium",
+                                   "postmarketos-base",
+                                   "uboot-tools"]
+
     assert deviceinfo["generate_legacy_uboot_initfs"] == "true"
